@@ -1,4 +1,5 @@
 from .basic_commands import try_traceback
+from .basic_commands import _func_timer
 from .basic_commands import func_timer
 
 from .basic_commands import fprint
@@ -14,5 +15,4 @@ from .basic_commands import join_path
 from .basic_commands import chunker
 from .basic_commands import create_json
 from .basic_commands import read_json
-from .basic_commands import write_json
-from .basic_commands import fd
\ No newline at end of file
+from .basic_commands import write_json
\ No newline at end of file
