@@ -6,6 +6,81 @@ from typing     import Any, Optional
 from time   import perf_counter
 from os     import mkdir, listdir, remove
 
+class FunctionTimer:
+    def __init__(self) -> None:
+        self.do_print:bool = True
+        self.ret_time:bool = False
+        self.skip_intro:bool = True
+        self.skip_inputs:bool = True
+
+    def config(self, **kwargs):
+        if 'do_print' in kwargs:
+            self.do_print = kwargs['do_print']
+        if 'ret_time' in kwargs:
+            self.ret_time = kwargs['ret_time']
+        if 'skip_inputs' in kwargs:
+            self.skip_inputs = kwargs['skip_inputs']
+
+    def _func_timer(self, do_print:bool=True, ret_time:bool=False, skip_intro:bool=True, skip_inputs:bool=True):
+        def timer(func):
+            @wraps(func)
+            def wrapper(*args, **kwargs):
+                fprint(f'Function timer started: {self._get_func_name(func)}', do_print=not skip_intro and do_print)
+                
+                time_start = perf_counter()
+                ret_val = func(*args, **kwargs)
+                time_delta = perf_counter() - time_start
+
+                self._print_time(func, time_delta, skip_inputs, do_print, *args, **kwargs)
+
+                if ret_time:
+                    return ret_val, time_delta
+                return ret_val
+            return wrapper
+        return timer
+    
+    def __call__(self, func, *args, **kwargs):
+        fprint(f'Function timer started: {self._get_func_name(func)}', do_print=not self.skip_intro and self.do_print)
+        
+        time_start = perf_counter()
+        ret_val = func(*args, **kwargs)
+        time_delta = perf_counter() - time_start
+        
+        self._print_time(func, time_delta, self.skip_inputs, self.do_print, *args, **kwargs)
+
+        if self.ret_time:
+            return ret_val, time_delta
+        return ret_val
+
+    def _get_func_name(self, func):
+        try:
+            return func.__name__
+        except:
+            try:
+                return func.__class__.__name__
+            except Exception:
+                return ''
+        
+
+    def _print_time(self, func, time_delta:float, skip_inputs:bool, do_print:bool, *args, **kwargs):
+        if not do_print:
+            return
+
+        func_name = self._get_func_name(func)
+        if round(time_delta, 4) == 0.0:
+            time_delta = f'0.0000...'
+        else:
+            time_delta = round(time_delta, 4)
+
+        if skip_inputs:
+            fprint(f'Function {func_name} Took {time_delta} seconds to run')
+        else:
+            fprint(f'Function {func_name} {args}{kwargs} Took {time_delta} seconds to run')
+
+_func_timer = FunctionTimer()._func_timer
+func_timer = FunctionTimer()
+
+
 def try_traceback(skip_traceback=False):
     """Decorator to catch and handle exceptions raised by a function.
     
@@ -29,32 +104,6 @@ def try_traceback(skip_traceback=False):
     return try_except
 
 
-def func_timer(ret_time=False, do_print=True):
-    """Decorator to measure the runtime of a function.
-    
-    Parameters:
-    - `ret_time` (bool): Whether to return the time taken by the function in addition to its return value.
-    - `do_print` (bool): Whether to print the time taken by the function.
-    
-    Returns:
-    - `function`: The decorated function.
-    """
-
-    def timer(func):
-        @wraps(func)
-        def wrapper(*args, **kwargs):
-            fprint('Function timer started', do_print=do_print)
-            time_start = perf_counter()
-            ret_val = func(*args, **kwargs)
-            time_delta = perf_counter() - time_start
-            fprint(f'Function {func.__name__}{args} {kwargs} Took {time_delta:.4f} seconds to run', do_print=do_print)
-            if ret_time:
-                return ret_val, time_delta
-            return ret_val
-        return wrapper
-    return timer
-
-
 def fprint(*args:Any, nl:bool=True, flush:bool=False, do_print:bool=True, end:Optional[str]=None) -> None:
     """Print one or more objects to the console, with optional newline, flushing, and ending characters.
     
@@ -382,18 +431,34 @@ def get_dir_path_for_file(file_path:str, ret_val='a') -> Any:
     return dir_path, filename
 
 
-def join_path(*args, join_with='/'):
-    """Join a list of paths with a specified separator.
-    
-    Parameters:
-    - `args` (str): A list of paths to join.
-    - `join_with` (str): The separator to use when joining the paths. Default is '/'.
-    
-    Returns:
-    - `str`: The joined path.
-    """
+def join_path(*args:str, join_with='/', dir_end:bool=False):
+    r"""Join path segments together, removing certain characters (`<>:"/\|?*`) and adjust for correct slash direction.
 
-    return join_with.join(args)
+    Parameters:
+    - `*args`: One or more path segments to join
+    - `join_with`: The separator to use when joining the path segments
+    - `dir_end`: Specify whether to add join_with character at the end of the returned path
+
+    Return:
+    A `string` representing the joined path
+    """
+    
+    def split_join(var:str, split_with:str=' '):
+        return join_with.join(var.split(split_with))
+
+    new_args = []
+    for arg in args:
+        arg = split_join(split_join(arg, '\\'), '/')
+        arg = arg.translate({ord(c): None for c in '<>:"|?*'})
+
+        new_args.append(arg)
+
+    out_path = join_with.join(new_args)
+
+    if dir_end:
+        out_path += join_with
+
+    return out_path
 
 
 def chunker(seq, size:int) -> Any:
